#' US States map in Geojson format (list)
#' 
#' This data comes from the \url{https://code.highcharts.com/mapdata/countries/us/us-all.js}
#' and is used in highmaps examples.
#'
#' @docType data
#' @name usgeojson
#' @usage usgeojson
#' @format A \code{list} in geojson format.
"usgeojson"
